@@ -1,17 +1,10 @@
 # -*- coding: utf-8 -*-
-# vim: autoindent shiftwidth=4 expandtab textwidth=80 tabstop=4 softtabstop=4
+# vim: autoindent shiftwidth=4 expandtab textwidth=120 tabstop=4 softtabstop=4
 
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2014 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
-# Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
-# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
-# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
-# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
-# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
-# Frode Woldsund, Martin Zibricky                                             #
+# Copyright (c) 2008-2016 OpenLP Developers                                   #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -27,20 +20,20 @@
 # Temple Place, Suite 330, Boston, MA 02111-1307 USA                          #
 ###############################################################################
 """
-The :mod:`languagemanager` module provides all the translation settings and
-language file loading for OpenLP.
+The :mod:`languagemanager` module provides all the translation settings and language file loading for OpenLP.
 """
 import logging
+import re
 import sys
 
-from PyQt4 import QtCore, QtGui
+from PyQt5 import QtCore, QtWidgets
 
-from openlp.core.utils import AppLocation
-from openlp.core.lib import translate
-from openlp.core.lib.settings import Settings
+
+from openlp.core.common import AppLocation, Settings, translate, is_win, is_macosx
 
 log = logging.getLogger(__name__)
 
+
 class LanguageManager(object):
     """
     Helper for Language selection
@@ -53,8 +46,7 @@ class LanguageManager(object):
         """
         Set up a translator to use in this instance of OpenLP
 
-        ``language``
-            The language to load into the translator
+        :param language: The language to load into the translator
         """
         if LanguageManager.auto_language:
             language = QtCore.QLocale.system().name()
@@ -62,11 +54,10 @@ class LanguageManager(object):
         app_translator = QtCore.QTranslator()
         app_translator.load(language, lang_path)
         # A translator for buttons and other default strings provided by Qt.
-        if sys.platform != u'win32' and sys.platform != u'darwin':
-            lang_path = QtCore.QLibraryInfo.location(
-                QtCore.QLibraryInfo.TranslationsPath)
+        if not is_win() and not is_macosx():
+            lang_path = QtCore.QLibraryInfo.location(QtCore.QLibraryInfo.TranslationsPath)
         default_translator = QtCore.QTranslator()
-        default_translator.load(u'qt_%s' % language, lang_path)
+        default_translator.load('qt_%s' % language, lang_path)
         return app_translator, default_translator
 
     @staticmethod
@@ -74,44 +65,35 @@ class LanguageManager(object):
         """
         Find all available language files in this OpenLP install
         """
-        log.debug(u'Translation files: %s', AppLocation.get_directory(
-            AppLocation.LanguageDir))
-        trans_dir = QtCore.QDir(AppLocation.get_directory(
-            AppLocation.LanguageDir))
-        file_names = trans_dir.entryList(QtCore.QStringList(u'*.qm'),
-                QtCore.QDir.Files, QtCore.QDir.Name)
+        log.debug('Translation files: %s', AppLocation.get_directory(AppLocation.LanguageDir))
+        trans_dir = QtCore.QDir(AppLocation.get_directory(AppLocation.LanguageDir))
+        file_names = trans_dir.entryList(['*.qm'], QtCore.QDir.Files, QtCore.QDir.Name)
         # Remove qm files from the list which start with "qt_".
-        file_names = file_names.filter(QtCore.QRegExp("^(?!qt_)"))
-        for name in file_names:
-            file_names.replaceInStrings(name, trans_dir.filePath(name))
-        return file_names
+        file_names = [file_ for file_ in file_names if not file_.startswith('qt_')]
+        return list(map(trans_dir.filePath, file_names))
 
     @staticmethod
     def language_name(qm_file):
         """
         Load the language name from a language file
 
-        ``qm_file``
-            The file to obtain the name from
+        :param qm_file: The file to obtain the name from
         """
         translator = QtCore.QTranslator()
         translator.load(qm_file)
-        return translator.translate('OpenLP.MainWindow', 'English',
-            'Please add the name of your language here')
+        return translator.translate('OpenLP.MainWindow', 'English', 'Please add the name of your language here')
 
     @staticmethod
     def get_language():
         """
         Retrieve a saved language to use from settings
         """
-        settings = Settings()
-        language = unicode(settings.value(
-            u'general/language', QtCore.QVariant(u'[en]')).toString())
-        log.info(u'Language file: \'%s\' Loaded from conf file' % language)
-        reg_ex = QtCore.QRegExp("^\[(.*)\]")
-        if reg_ex.exactMatch(language):
+        language = Settings().value('core/language')
+        language = str(language)
+        log.info('Language file: \'%s\' Loaded from conf file' % language)
+        if re.match(r'[[].*[]]', language):
             LanguageManager.auto_language = True
-            language = reg_ex.cap(1)
+            language = re.sub(r'[\[\]]', '', language)
         return language
 
     @staticmethod
@@ -119,31 +101,27 @@ class LanguageManager(object):
         """
         Set the language to translate OpenLP into
 
-        ``action``
-            The language menu option
-
-        ``message``
-            Display the message option
+        :param action:  The language menu option
+        :param message:  Display the message option
         """
-        language = u'en'
+        language = 'en'
         if action:
-            action_name = unicode(action.objectName())
-            if action_name == u'autoLanguageItem':
+            action_name = str(action.objectName())
+            if action_name == 'autoLanguageItem':
                 LanguageManager.auto_language = True
             else:
                 LanguageManager.auto_language = False
                 qm_list = LanguageManager.get_qm_list()
-                language = unicode(qm_list[action_name])
+                language = str(qm_list[action_name])
         if LanguageManager.auto_language:
-            language = u'[%s]' % language
-        Settings().setValue(
-            u'general/language', QtCore.QVariant(language))
-        log.info(u'Language file: \'%s\' written to conf file' % language)
+            language = '[%s]' % language
+        Settings().setValue('core/language', language)
+        log.info('Language file: \'%s\' written to conf file' % language)
         if message:
-            QtGui.QMessageBox.information(None,
-                translate('OpenLP.LanguageManager', 'Language'),
-                translate('OpenLP.LanguageManager',
-                    'Please restart OpenLP to use your new language setting.'))
+            QtWidgets.QMessageBox.information(None,
+                                              translate('OpenLP.LanguageManager', 'Language'),
+                                              translate('OpenLP.LanguageManager',
+                                                        'Please restart OpenLP to use your new language setting.'))
 
     @staticmethod
     def init_qm_list():
@@ -155,9 +133,8 @@ class LanguageManager(object):
         for counter, qmf in enumerate(qm_files):
             reg_ex = QtCore.QRegExp("^.*i18n/(.*).qm")
             if reg_ex.exactMatch(qmf):
-                name = u'%s' % reg_ex.cap(1)
-                LanguageManager.__qm_list__[u'%#2i %s' % (counter + 1,
-                    LanguageManager.language_name(qmf))] = name
+                name = '%s' % reg_ex.cap(1)
+                LanguageManager.__qm_list__['%#2i %s' % (counter + 1, LanguageManager.language_name(qmf))] = name
 
     @staticmethod
     def get_qm_list():
